package com.perforce.maven.scm.provider.p4.manager;

import java.io.File;

import org.junit.Assert;
import org.junit.Test;

import com.perforce.maven.scm.provider.p4.AbstractPlexusTestCase;
import com.perforce.maven.scm.provider.p4.P4ScmTestUtils;
import com.perforce.maven.scm.provider.p4.repository.P4ScmProviderRepository;
import com.perforce.maven.scm.provider.p4.util.P4ScmUrl;
import com.perforce.maven.scm.provider.p4.util.P4Utils;
import com.perforce.p4java.client.IClient;
import com.perforce.p4java.exception.ConnectionException;

public class P4ClientManagerTest
    extends AbstractPlexusTestCase
{

    @Test
    public void testCreateClientManager()
        throws Exception
    {

        P4ScmTestUtils.initRepo();

        P4ClientManager clientManager = (P4ClientManager) this.lookup( P4ClientManager.ROLE );

        P4ScmUrl p4Url = P4ScmUrl.parse( P4ScmTestUtils.getScmUrl() );

        P4ScmProviderRepository repo =
            new P4ScmProviderRepository( p4Url.getProtocol(), p4Url.getHost(), p4Url.getPort(), p4Url.getPath(),
                                         p4Url.getUsername(), p4Url.getPassword() );

        IClient client = clientManager.getClient( repo, new File( getBuildDirectory(), "client" ) );

        IClient client2 = clientManager.getClient( repo, new File( getBuildDirectory(), "client" ) );

        Assert.assertSame( client, client2 );

        // force a stale client
        client.getServer().disconnect();

        P4Utils.getSettings().setCheckStaledConnection( true );
        client = clientManager.getClient( repo, new File( getBuildDirectory(), "client" ) );
        P4Utils.getSettings().setCheckStaledConnection( false );//return back to default
        // got another client
        Assert.assertNotSame( client, client2 );

        try
        {
            client2.getServer().getUser( null );
            Assert.fail( "Stale connection expected" );
        }
        catch ( ConnectionException e )
        {
        }

    }
}
